@@ -15,7 +15,4 @@ from .API.TickDataAPI.DWX_TickData_Reader_API import DWX_TickData_Reader_API
 from .API.DarwinDataAnalyticsAPI.DWX_Data_Analytics_API import DWX_Darwin_Data_Analytics_API
 
 # Minions:
-from .MINIONS.dwx_graphics_helpers import DWX_Graphics_Helpers
-
-# Apps:
-from .APPS.API_Helpers import TS_Calculations
+from .MINIONS.dwx_graphics_helpers import DWX_Graphics_Helpers
\ No newline at end of file
